@@ -7,7 +7,7 @@ import hildon
 from os import path, system
 from ConfigParser import SafeConfigParser
 
-version = "1.1-1"
+version = "1.1-2"
 autostart = False
 confirmDisconnect = True
 stopTracking = False
@@ -19,7 +19,8 @@ class Main(object):
         global confirmDisconnect
         global stopTracking
         global skipSystemCheck
-        
+        autostartDisabled = False
+       
         self.parser = SafeConfigParser()
         self.parser.optionxform = str
         if not path.isfile("/home/user/.openssh-status-widget"):
@@ -45,8 +46,12 @@ class Main(object):
         lines = sshFile.readlines()
         sshFile.close()
         for line in lines:
-            if line[0:20] == "start on stopped rcS":
+            if line.strip('\n').strip(' ') == "start on stopped rcS":
                 autostart = True
+            if line.strip('\n').strip(' ') == "#start on stopped rcS":
+                autostartDisabled = True
+        if not autostart and not autostartDisabled:
+            system("sudo sed -i '1i#start on stopped rcS' /etc/event.d/sshd")
             
         self.main()
     
@@ -105,9 +110,9 @@ class Main(object):
         global autostart
         autostart = not autostart
         if autostart:
-            system("sudo sed -i 's/#start[[:blank:]]on stopped rcS/start on stopped rcS/g' /etc/event.d/sshd")
+            system("sudo sed -i 's/#start on stopped rcS/start on stopped rcS/g' /etc/event.d/sshd")
         else:
-            system("sudo sed -i 's/start[[:blank:]]on stopped rcS/#start on stopped rcS/g' /etc/event.d/sshd")
+            system("sudo sed -i 's/start on stopped rcS/#start on stopped rcS/g' /etc/event.d/sshd")
 
     def buttonConfirm_clicked(self, dummy):
         global confirmDisconnect
