@@ -98,8 +98,8 @@ class opensshStatus(hildondesktop.StatusMenuItem):
         
     def adjustSshFile(self):
         self.dialog = gtk.Dialog("OpenSSH status", None)
-        text = gtk.Label("The widget has detected a system configuration for restarting the OpenSSH server. "
-        "For error-free function of this widget restarting the server should be disabled.\n\nDo you want the widget to disable it now?\n")
+        text = gtk.Label("The widget has detected a system configuration for respawning the OpenSSH server. "
+        "For error-free function of this widget respawning the server should be disabled.\n\nDo you want the widget to disable it now?\n")
         text.set_line_wrap(True)
         self.dialog.vbox.pack_start(text)
         buttonYes = self.dialog.add_button("Yes", gtk.RESPONSE_YES)
